<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_HK" version="2.1">
<context>
    <name>TabManagerButton</name>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="50"/>
        <source>Tab Manager button</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TabManagerSettings</name>
    <message>
        <location filename="../tabmanagersettings.ui" line="14"/>
        <source>Tab Manager Settings</source>
        <translation>分頁管理員設定</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="20"/>
        <source>View</source>
        <translation>檢視</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="26"/>
        <source>Please select view type:</source>
        <translation>請選取檢視類型：</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="33"/>
        <source>SideBar</source>
        <translation>側邊欄</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="40"/>
        <source>Window</source>
        <translation>視窗</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="47"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note:&lt;/span&gt; The &amp;quot;Window&amp;quot; type is recommended for managing lots of windows/tabs.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;注意：&lt;/span&gt;建議使用「視窗」類型來管理大量視窗╱分頁。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="60"/>
        <source>Use TabManager plugin as replacement for main TabBar.</source>
        <translation>使用分頁管理員外掛程式取代主分頁列。</translation>
    </message>
</context>
<context>
    <name>TabManagerWidget</name>
    <message>
        <location filename="../tabmanagerwidget.ui" line="14"/>
        <source>Tab Manager</source>
        <translation>分頁管理員</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="110"/>
        <source>Local File System:</source>
        <translation>本地檔案系統：</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="113"/>
        <source>QupZilla:</source>
        <translation>QupZilla：</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="116"/>
        <source> [FTP]</source>
        <translation> [FTP]</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="301"/>
        <source>Group by</source>
        <translation>分組按照</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="302"/>
        <source>&amp;Window</source>
        <translation>視窗（&amp;W）</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="307"/>
        <source>&amp;Domain</source>
        <translation>域名（&amp;D）</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="312"/>
        <source>&amp;Host</source>
        <translation>主機（&amp;H）</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="320"/>
        <source>&amp;Show side by side</source>
        <translation>並排顯示（&amp;S）</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="326"/>
        <source>&amp;Detach checked tabs</source>
        <translation>所選分頁移往新視窗（&amp;D）</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="327"/>
        <source>Book&amp;mark checked tabs</source>
        <translation>所選分頁加入到書籤（&amp;M）</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="328"/>
        <source>&amp;Close checked tabs</source>
        <translation>關閉所選分頁（&amp;C）</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="329"/>
        <source>&amp;Unload checked tabs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="581"/>
        <source>Choose folder for bookmarks:</source>
        <translation>選取書籤資料夾：</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="582"/>
        <source>Bookmark Selected Tabs</source>
        <translation>所選分頁加入到書籤</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="700"/>
        <source>Window %1</source>
        <translation>視窗%1</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="701"/>
        <source>Double click to switch</source>
        <translation>按兩下切換</translation>
    </message>
</context>
<context>
    <name>TabManagerWidgetController</name>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="68"/>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="73"/>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="99"/>
        <source>Tab Manager</source>
        <translation>分頁管理員</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="100"/>
        <source>Show Tab Manager</source>
        <translation>顯示分頁管理員</translation>
    </message>
</context>
</TS>